﻿using Hotline.Share.Enums.Order;
using Hotline.Share.Requests;

namespace Hotline.Share.Dtos.Settings
{
    public record AddTimeLimitDto
    {
        /// <summary>
        /// 配置名称
        /// </summary>
        public string TimeLimitName { get; set; }

        /// <summary>
        /// 业务名称
        /// </summary>
        public string WorkflowName { get; set; }

        /// <summary>
        /// 业务编码
        /// </summary>
        public string WorkflowCode { get; set; }

        /// <summary>
        /// 已配置参数
        /// </summary>
        public List<ParamTypeModel>? ParamArr { get; set; }

        /// <summary>
        /// 排序
        /// </summary>
        public List<PriorityModel>? Priority { get; set; }

        /// <summary>
        /// 组合
        /// </summary>
        public List<CombinationModel>? Combination { get; set; }
    }

    #region Model

    public class CombinationModel
    {
        /// <summary>
        /// 组合ID
        /// </summary>
        public string Id { get; set; }

        /// <summary>
        /// 组合名称
        /// </summary>
        public string CombinationName { get; set; }


        /// <summary>
        /// 组合参数
        /// </summary>
        public List<CombinationParamModel> CombinationParam { get; set; }


        /// <summary>
        /// 时限
        /// </summary>
        public int TimeLimitValue { get; set; }
        /// <summary>
        /// 时限类型
        /// </summary>
        public string TimeLimit { get; set; }

        /// <summary>
        /// 换算时间（小时）
        /// </summary>
        public int Hour { get; set; }
    }


    public class CombinationParamModel
    {
        /// <summary>
        /// 参数类型Code
        /// </summary>
        public string Code { get; set; }

        /// <summary>
        /// 组合参数名称
        /// </summary>
        public string ParamName { get; set; }

        /// <summary>
        /// 组合参数值
        /// </summary>
        public string ParamValue { get; set; }
    }



    public class PriorityModel
    {
        public string Id { get; set; }

        public string ParamTypeName { get; set; }

        public int Sort { get; set; }
    }


    public class ParamTypeModel
    {
        public string ParamType { get; set; }

        public List<ParamValueModel> ParamValue { get; set; }
    }

    public class ParamValueModel
    {
        public string Id { get; set; }
        /// <summary>
        /// 
        /// </summary>
        public string ParamTypeName { get; set; }
        /// <summary>
        /// 时限
        /// </summary>
        public int TimeLimitValue { get; set; }
        /// <summary>
        /// 时限类型
        /// </summary>
        public string TimeLimit { get; set; }

        /// <summary>
        /// 换算时间（小时）
        /// </summary>
        public int Hour { get; set; }
    }

    #endregion

    public record UpdateTimeLimitDto : AddTimeLimitDto
    {
        public string Id { get; set; }
    }

    public record QueryPagedTimeLimitPagedDto : PagedKeywordRequest
    {

    }
}
